| Title: | Real-Time PCR Data Sets by Rutledge et al. (2004) |
|---|---|
| Description: | Real-time quantitative polymerase chain reaction (qPCR) data by Rutledge et al. (2004) <doi:10.1093/nar/gnh177> in tidy format. The data comprises a six-point, ten-fold dilution series, repeated in five independent runs, for two different amplicons. In each run, each standard concentration is replicated four times. For the original raw data file see the Supplementary Data section: <https://academic.oup.com/nar/article/32/22/e178/2375678#supplementary-data>. |
| Authors: | Ramiro Magno [aut, cre] (ORCID: <https://orcid.org/0000-0001-5226-3441>), Pattern Institute [cph, fnd] |
| Maintainer: | Ramiro Magno <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.1.1 |
| Built: | 2026-05-20 06:21:53 UTC |
| Source: | https://github.com/ramiromagno/rutledge |
Each data set comprises a six-point, ten-fold dilution series, repeated in five independent runs, for two different amplicons: K1/K2, 102 bp, and K3/K2, 218 bp. Fluorescence readings were exported after background subtraction via baseline averaging of the 5 cycles immediately preceding the cycles in which fluorescence was first detected. Please read the Materials and Methods section of Rutledge et al. (2004) for more details.
A tibble with 10,800 rows and 10 variables:
platePlate identifier. Because one plate (run) was used per
dilution series, plate values are simply numbered 1 thru 5.
wellWell identifier. Values are always NA (not available). This
variable is kept nevertheless to be coherent with other data sets from other
similar R data packages.
dyeThe type of dye used. In this data set the values are always
"SYBR", meaning SYBR Green I master mix (Roche).
targetTarget identifier: the amplicon used, K1/K2 or K3/K2.
sample_typeSample type (all curves are standards, i.e. "std").
replicateReplicate identifier: 1 thru 4.
copiesStandard copy number.
dilutionDilution factor. Higher number means greater dilution.
cyclePCR cycle.
fluorRaw fluorescence values.
rutledgerutledge